@@ -4,15 +4,16 @@
 #![feature(auto_traits)]
 #![feature(trait_alias)]
 #![feature(associated_type_defaults)]
-#![feature(explicit_generic_args_with_impl_trait)]
 #![feature(generic_arg_infer)]
 #![feature(generic_associated_types)]
-#![feature(specialization)]
+
+#![doc = include_str!("../README.md")]
 
 pub mod prelude;
-mod grant;
-mod principal;
-mod grant_chain;
+mod subject;
+mod attributes;
+mod attribute_chain;
+mod resource;
 
-/// Is the label applied to grant checks that are not resource dependant.
-pub const DEFAULT_GRANT_LABEL: &'static str = "GrantCheck::__";
\ No newline at end of file
+#[doc(hidden)]
+pub const DEFAULT_ATTRIBUTE_TAG: &'static str = "AttributeTag::DEFAULT";
